@@ -45,31 +45,42 @@ void Access::init()
 void Access::getcache()
 {
     QString orgData;
-    init();
-    
-    QString cachePath = Kita::Cache::getPath( m_datURL );
 
-    if ( cachePath != QString::null ) {
-        QFile file( cachePath );
-        if ( file.open( IO_ReadOnly ) ) {
-            orgData += file.readAll();
-            file.close();
-        }
+    // get cache path.
+    QString cachePath = Kita::Cache::getPath( m_datURL );
+    if ( cachePath == QString::null ) {
+        return;
     }
 
-    if( orgData == QString::null ) return;
+    // read cache file.
+    QFile file( cachePath );
+    if ( file.open( IO_ReadOnly ) ) {
+        orgData += file.readAll();
+        file.close();
+    }
+
+    // set data size.
+    if ( orgData == QString::null ) return ;
     m_dataSize = orgData.length();
 
-    /* Machi BBS's data is already parsed as 2ch dat. */
-    if( m_bbstype == Board_MachiBBS ){
+    switch ( m_bbstype ) {
 
-	QString tmpData = Kita::qcpToUnicode( orgData );
-	QStringList tmpList = QStringList::split( "\n", tmpData );
-	emit receiveData( tmpList );
-	return;
+    case Board_2ch:
+    case Board_MachiBBS:  /* Machi BBS's data is already parsed as 2ch dat. */
+
+        {
+            QString tmpData = Kita::qcpToUnicode( orgData );
+            QStringList tmpList = QStringList::split( "\n", tmpData );
+            emit receiveData( tmpList );
+        }
+        break;
+
+    default:
+        /* convert data stream into 2ch dat.
+        and emit receiveData SIGNAL.        */
+        emitDatLineList( orgData );
+        break;
     }
-    
-    emitDatLineList( orgData );
 }
 
 /* write data to cache */ /* protected */
@@ -101,33 +112,33 @@ bool Access::getupdate( int readNum )
     m_threadData = QString::null;
     m_firstReceive = FALSE;
     m_invalidDataReceived = FALSE;
-    m_lastLine = QString::null;       
+    m_lastLine = QString::null;
 
     /* set URL of data */
     QString getURL;
-    switch( m_bbstype ){
+    switch ( m_bbstype ) {
 
     case Board_MachiBBS:
-	getURL = Kita::getThreadURL( m_datURL );
-	if( m_readNum > 0 ) getURL += "&START=" + QString().setNum( m_readNum +1 );
-	Kita::InitParseMachiBBS();
-	break;
+        getURL = Kita::getThreadURL( m_datURL );
+        if ( m_readNum > 0 ) getURL += "&START=" + QString().setNum( m_readNum + 1 );
+        Kita::InitParseMachiBBS();
+        break;
 
     case Board_JBBS:
-	getURL = Kita::getThreadURL( m_datURL );
-	getURL.replace( "read.cgi", "rawmode.cgi" );  /* adhoc... */
-	if( m_readNum > 0 ) getURL += "/" + QString().setNum( m_readNum +1 ) + "-";
-	break;
+        getURL = Kita::getThreadURL( m_datURL );
+        getURL.replace( "read.cgi", "rawmode.cgi" );  /* adhoc... */
+        if ( m_readNum > 0 ) getURL += "/" + QString().setNum( m_readNum + 1 ) + "-";
+        break;
 
     default:
-	getURL = m_datURL.prettyURL();
+        getURL = m_datURL.prettyURL();
     }
-    
+
     /* set UserAgent */
     const QString useragent = QString( "Monazilla/1.00 (Kita/%1)" ).arg( VERSION );
     KIO::SlaveConfig::self() ->setConfigData( "http",
-					      KURL( getURL ).host(),
-					      "UserAgent", useragent );
+            KURL( getURL ).host(),
+            "UserAgent", useragent );
 
     /* create new job */
     KIO::TransferJob* job = KIO::get( getURL, true, false );
@@ -142,8 +153,8 @@ bool Access::getupdate( int readNum )
 
     /* resume */
     if ( m_bbstype != Board_MachiBBS
-	  && m_bbstype != Board_JBBS
-	  && m_dataSize > 0 ) {
+            && m_bbstype != Board_JBBS
+            && m_dataSize > 0 ) {
         m_firstReceive = TRUE; /* remove first char (i.e. \n). see also slotReceiveThreadData() */
         job->addMetaData( "resume", QString::number( m_dataSize - 1 ) );
         job->addMetaData( "AllowCompressedPage", "false" );
@@ -169,13 +180,13 @@ void Access::slotReceiveThreadData( KIO::Job*, const QByteArray& data )
 {
     QString cstr( data );
 
-    if( m_bbstype == Board_MachiBBS
-	|| m_bbstype == Board_JBBS ){
-	
-	emitDatLineList( cstr );
-	return;
+    if ( m_bbstype == Board_MachiBBS
+            || m_bbstype == Board_JBBS ) {
+
+        emitDatLineList( cstr );
+        return ;
     }
-    
+
     /* check if received data is invalid ( or broken ). */
     if ( ( m_dataSize > 0 && responseCode() != 206 )
             || ( m_firstReceive && cstr[ 0 ] != '\n' )
@@ -200,7 +211,7 @@ void Access::emitDatLineList( const QString& dataStream )
 {
     QStringList lineList;
     QStringList datLineList;
-    if( dataStream == QString::null ) return;
+    if ( dataStream == QString::null ) return ;
 
     bool endIsLF = FALSE;
     if ( dataStream.at( dataStream.length() - 1 ) == '\n' ) endIsLF = TRUE;
@@ -208,75 +219,75 @@ void Access::emitDatLineList( const QString& dataStream )
     /* split the stream */
     m_lastLine += dataStream;
     lineList = QStringList::split( "\n", m_lastLine );
-    m_lastLine = QString::null;    
+    m_lastLine = QString::null;
 
     /* save the last line */
-    if( !endIsLF ){
+    if ( !endIsLF ) {
+
+        QStringList::iterator lastit = lineList.end();
+        lastit--;
+        if ( lastit != lineList.end() ) {
 
-	QStringList::iterator lastit = lineList.end();
-      lastit--;
-       if ( lastit != lineList.end() ) {
-	    
             m_lastLine = ( *lastit );
             lineList.remove( lastit );
         }
     }
 
     /* filtering */
-    
+
     /* convert lines into 2ch dat */
     int count = lineList.count();
-    for ( int i = 0; i < count ; ++i ){
+    for ( int i = 0; i < count ; ++i ) {
 
         if ( lineList[ i ] != QString::null ) {
-	    
-	    QString line;
-	    int nextNum = m_readNum +1;
 
-	    /* convert line */
-	    switch( m_bbstype ){
+            QString line;
+            int nextNum = m_readNum + 1;
 
-	    case Board_MachiBBS:
-		line = Kita::ParseMachiBBSOneLine( lineList[ i ] , nextNum );
-		break;
-		
-	    case Board_JBBS:
-		line = Kita::ParseJBBSOneLine( lineList[ i ] , nextNum );
-		break;
+            /* convert line */
+            switch ( m_bbstype ) {
 
-	    case Board_FlashCGI:
-		line = Kita::ParseFlashCGIOneLine( lineList[ i ] );
-		break;
+            case Board_MachiBBS:
+                line = Kita::ParseMachiBBSOneLine( lineList[ i ] , nextNum );
+                break;
 
-	    default:
-		line = lineList[ i ];
-	    }
+            case Board_JBBS:
+                line = Kita::ParseJBBSOneLine( lineList[ i ] , nextNum );
+                break;
 
-	    if( line == QString::null ) continue;
+            case Board_FlashCGI:
+                line = Kita::ParseFlashCGIOneLine( lineList[ i ] );
+                break;
 
-	    /* add abone lines */
-	    const QString aboneStr = "abone<><><>abone<>";
-	    while( nextNum > m_readNum +1 ){
-		datLineList += aboneStr;
-		m_threadData += aboneStr +"\n";
-		++m_readNum;
-	    }
+            default:
+                line = lineList[ i ];
+            }
 
-	    /* save line */
-	    if( m_bbstype == Board_MachiBBS ) m_threadData += line + "\n";
-	    else m_threadData += lineList[ i ] + "\n";
-	    ++m_readNum;
+            if ( line == QString::null ) continue;
 
-	    /* encode line */
-	    switch( m_bbstype ){
+            /* add abone lines */
+            const QString aboneStr = "abone<><><>abone<>";
+            while ( nextNum > m_readNum + 1 ) {
+                datLineList += aboneStr;
+                m_threadData += aboneStr + "\n";
+                ++m_readNum;
+            }
 
-	    case Board_JBBS:
-		datLineList += Kita::ecuToUnicode( line );
-		break;
+            /* save line */
+            if ( m_bbstype == Board_MachiBBS ) m_threadData += line + "\n";
+            else m_threadData += lineList[ i ] + "\n";
+            ++m_readNum;
 
-	    default:
-		datLineList += Kita::qcpToUnicode( line );
-	    }
+            /* encode line */
+            switch ( m_bbstype ) {
+
+            case Board_JBBS:
+                datLineList += Kita::ecuToUnicode( line );
+                break;
+
+            default:
+                datLineList += Kita::qcpToUnicode( line );
+            }
         }
     }
 
@@ -334,6 +345,17 @@ int Access::responseCode()
     }
 }
 
+/* public */
+const int Access::dataSize() const
+{
+    return m_dataSize;
+}
+
+/* public */
+const bool Access::invalidDataReceived() const
+{
+    return m_invalidDataReceived;
+}
 
 //
 // access offlaw.cgi
@@ -393,7 +415,7 @@ void OfflawAccess::slotReceiveThreadData( KIO::Job*, const QByteArray& data )
     if ( m_invalidDataReceived ) return ;
 
     // "+OK ....../1024K\tLocation:temp/\n"
-    if ( m_threadData.isEmpty() && cstr[0] == '+' ) {
+    if ( m_threadData.isEmpty() && cstr[ 0 ] == '+' ) {
         // skip first line.
         int index = cstr.find( '\n' );
         cstr = cstr.mid( index + 1 );
