@@ -39,6 +39,7 @@ KitaConfig::KitaConfig()
         m_aboneNameList( KitaConfig::defaultAboneNameList() ),
         m_aboneIDList( KitaConfig::defaultAboneIDList() ),
         m_aboneWordList( KitaConfig::defaultAboneWordList() ),
+        m_aboneChain( KitaConfig::defaultAboneChain() ),
         m_MarkTime( KitaConfig::defaultMarkTime() ),
         m_alwaysUseTab( KitaConfig::defaultAlwaysUseTab() ),
         m_sortOrder( static_cast<SortOrder>( KitaConfig::defaultSortOrder() ) ),
@@ -52,7 +53,9 @@ KitaConfig::KitaConfig()
         m_partMimeList( KitaConfig::defaultPartMimeList() ),
         m_userID( KitaConfig::defaultUserID() ),
         m_password( KitaConfig::defaultPassword() ),
-        m_autoLogin( KitaConfig::defaultAutoLogin() )
+        m_checkResponsed( KitaConfig::defaultCheckResponsed() ),
+        m_autoLogin( KitaConfig::defaultAutoLogin() ),
+        m_copyOnClick( KitaConfig::defaultCopyOnClick() )
 {}
 
 KitaConfig::~KitaConfig()
@@ -77,6 +80,8 @@ void KitaConfig::writeConfig( KConfig* config )
     config->writeEntry( "UseKitaNavi", KitaConfig::useKitaNavi() );
     config->writeEntry( "UseStyleSheet", KitaConfig::useStyleSheet() );
     config->writeEntry( "PartMimeList", KitaConfig::partMimeList() );
+    config->writeEntry( "AboneChain", KitaConfig::aboneChain() );
+    config->writeEntry( "CheckResponsed", KitaConfig::checkResponsed() );
 
     config->setGroup( "Color" );
     config->writeEntry( "Thread", KitaConfig::threadColor() );
@@ -125,7 +130,9 @@ void KitaConfig::readConfig( KConfig* config )
 
     KitaConfig::setUseKitaNavi( config->readBoolEntry( "UseKitaNavi", KitaConfig::defaultUseKitaNavi() ) );
     KitaConfig::setUseStyleSheet( config->readBoolEntry( "UseStyleSheet", KitaConfig::defaultUseStyleSheet() ) );
-
+    KitaConfig::setAboneChain( config->readBoolEntry( "AboneChain", KitaConfig::defaultAboneChain() ) );
+    KitaConfig::setCheckResponsed( config->readBoolEntry( "CheckResponsed", KitaConfig::defaultCheckResponsed() ) );
+    KitaConfig::setCopyOnClick( config->readBoolEntry( "CopyOnClick", KitaConfig::defaultCopyOnClick() ) );
     {
         // MIME list
         QStringList mimeList = config->readListEntry( "PartMimeList" );
@@ -207,30 +214,28 @@ QString KitaConfig::defaultStyleSheetText()
                "body,\n"
                "body.pop {\n"
                "}\n"
-               "table.res_title,\n"
-               "table.pop_res_title {\n"
+
+               "a.coloredLink:link\n"
+               "{\n"
+               " color: magenta;"
+               "}\n"
+
+               "div.res_title,\n"
+               "div.pop_res_title {\n"
                "  white-space: nowrap;\n"
+               "  padding-bottom: .2em;\n"
                "}\n"
-               "td.res_title_number,\n"
-               "td.pop_res_title_number {\n"
-               "}\n"
-               "td.res_title_name,\n"
-               "td.pop_res_title_name {\n"
-               "}\n"
-               "td.res_title_date,\n"
-               "td.pop_res_title_date {\n"
-               "}\n"
-               "td.res_title_id,\n"
-               "td.pop_res_title_id {\n"
+
+               "span.name_noaddr {\n"
+               "  color: green;\n"
                "}\n"
+
                "div.res_body,\n"
                "div.pop_res_body {\n"
                "  margin-left: 3.5em;\n"
-               "}\n"
-               "div.res_block,\n"
-               "div.pop_res_block {\n"
                "  padding-bottom: 1.8em;\n"
                "}\n"
+
                "div.kokoyon {\n"
                "  background-color: #CCCCCC;\n"
                "  text-align: center;\n"
