@@ -46,6 +46,7 @@ private:
     QStringList m_aboneNameList;
     QStringList m_aboneIDList;
     QStringList m_aboneWordList;
+    bool m_aboneChain;
     int m_MarkTime;
     bool m_alwaysUseTab;
     SortOrder m_sortOrder;
@@ -60,6 +61,8 @@ private:
     QString m_userID;
     QString m_password;
     bool m_autoLogin;
+    bool m_checkResponsed;
+    bool m_copyOnClick;
 
     KitaConfig();
     virtual ~KitaConfig();
@@ -132,6 +135,10 @@ public:
     static void setAboneIDList( QStringList list ) { getInstance() ->m_aboneIDList = list; }
     static void addAboneID( QString id ) { getInstance() ->m_aboneIDList.append( id ); }
 
+    static bool aboneChain() { return getInstance() ->m_aboneChain; }
+    static void setAboneChain( bool value ) { getInstance() ->m_aboneChain = value; }
+    static bool defaultAboneChain() { return false; }
+
     static QStringList& aboneWordList() { return getInstance() ->m_aboneWordList; }
     static void setAboneWordList( QStringList list ) { getInstance() ->m_aboneWordList = list; }
     static void addAboneWord( QString word ) { getInstance() ->m_aboneWordList.append( word ); }
@@ -195,6 +202,15 @@ public:
     static bool autoLogin() { return getInstance() ->m_autoLogin; }
     static void setAutoLogin( bool value ) { getInstance() ->m_autoLogin = value; }
     static bool defaultAutoLogin() { return false; }
+
+    static bool checkResponsed() { return getInstance() ->m_checkResponsed; }
+    static void setCheckResponsed( bool value ) { getInstance() ->m_checkResponsed = value; }
+    static bool defaultCheckResponsed() { return true; }
+
+    // read only (hidden setting)
+    static bool copyOnClick() { return getInstance() ->m_copyOnClick; }
+    static void setCopyOnClick( bool value ) { getInstance() ->m_copyOnClick = value; }
+    static bool defaultCopyOnClick() { return false; }
 };
 
 #endif
