@@ -66,14 +66,16 @@ KitaPreferences::KitaPreferences()
     QVBox * loginFrame = addVBoxPage( i18n( "Login" ), i18n( "Login" ) );
     m_loginPage = new Kita::LoginPrefPage( loginFrame );
 
-//    QVBox * debugFrame = addVBoxPage( i18n( "Debug" ), i18n( "Debug" ) );
-//    m_debugPage = new DebugPrefPage( debugFrame );
+    //    QVBox * debugFrame = addVBoxPage( i18n( "Debug" ), i18n( "Debug" ) );
+    //    m_debugPage = new DebugPrefPage( debugFrame );
 
     connect( m_facePage, SIGNAL( changed() ), SLOT( slotChanged() ) );
     connect( m_asciiArtPage, SIGNAL( changed() ), SLOT( slotChanged() ) );
     connect( m_uiPage, SIGNAL( changed() ), SLOT( slotChanged() ) );
     connect( m_abonePage, SIGNAL( changed() ), SLOT( slotChanged() ) );
     connect( m_loginPage, SIGNAL( changed() ), SLOT( slotChanged() ) );
+
+    connect( this, SIGNAL( aboutToShowPage( QWidget* ) ), SLOT( slotAboutToShowPage( QWidget* ) ) );
 }
 
 void KitaPreferences::slotApply()
@@ -152,6 +154,14 @@ void KitaPreferences::slotOk()
     KDialogBase::slotOk();
 }
 
+void KitaPreferences::slotAboutToShowPage( QWidget* page )
+{
+    if ( activePageIndex() == 1 ) {
+        // ascii art
+        m_asciiArtPage->init();
+    }
+}
+
 DebugPrefPage::DebugPrefPage( QWidget* parent )
         : DebugPrefBase( parent )
 {
@@ -176,22 +186,28 @@ void DebugPrefPage::replace()
                                      "Are you ready?" ), QMessageBox::Ok,
                                QMessageBox::Cancel | QMessageBox::Default | QMessageBox::Escape ) == QMessageBox::Ok ) {
 
-	if( BoardManager::moveBoard( fromURL, toURL ) )
-	    QMessageBox::information( this, i18n( "replace" ), i18n( "Complete." ) );
-	else KMessageBox::error( this, i18n( "replace" ), i18n( "Failed.." ) );
+        if ( BoardManager::moveBoard( fromURL, toURL ) )
+            QMessageBox::information( this, i18n( "replace" ), i18n( "Complete." ) );
+        else KMessageBox::error( this, i18n( "replace" ), i18n( "Failed.." ) );
     }
 }
 
 AsciiArtPrefPage::AsciiArtPrefPage( QWidget* parent )
         : AsciiArtPrefBase( parent )
 {
-    asciiArtText->setText( KitaConfig::asciiArtList().join( "\n" ) );
-    showAACheckBox->setChecked( KitaConfig::showAA() );
+    init();
 
     connect( asciiArtText, SIGNAL( textChanged() ), SIGNAL( changed() ) );
     connect( showAACheckBox, SIGNAL( clicked() ), SIGNAL( changed() ) );
 }
 
+void AsciiArtPrefPage::init()
+{
+    asciiArtText->setText( KitaConfig::asciiArtList().join( "\n" ) );
+    asciiArtText->setFont( KitaConfig::threadFont() );
+    showAACheckBox->setChecked( KitaConfig::showAA() );
+}
+
 void AsciiArtPrefPage::apply()
 {
     QString text = asciiArtText->text();
